==> myfaces-tobago-4.5.5-source-release.zip: tobago-4.5.5/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/HeaderFooterController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import javax.enterprise.context.SessionScoped;
import javax.inject.Named;
import java.io.Serializable;

@Named
@SessionScoped
public class HeaderFooterController implements Serializable {

  private boolean renderHeader = true;
  private boolean fixHeader = true;
  private boolean renderFooter = true;
  private boolean fixFooter = true;

  public boolean isRenderHeader() {
    return renderHeader;
  }

  public void setRenderHeader(boolean renderHeader) {
    this.renderHeader = renderHeader;
  }

  public boolean isFixHeader() {
    return fixHeader;
  }

  public void setFixHeader(boolean fixHeader) {
    this.fixHeader = fixHeader;
  }

  public boolean isRenderFooter() {
    return renderFooter;
  }

  public void setRenderFooter(boolean renderFooter) {
    this.renderFooter = renderFooter;
  }

  public boolean isFixFooter() {
    return fixFooter;
  }

  public void setFixFooter(boolean fixFooter) {
    this.fixFooter = fixFooter;
  }
}

==> myfaces-tobago-6.7.0-source-release.zip: tobago-6.7.0/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/HeaderFooterController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import jakarta.enterprise.context.SessionScoped;
import jakarta.inject.Named;

import java.io.Serializable;

@Named
@SessionScoped
public class HeaderFooterController implements Serializable {

  private boolean renderHeader = true;
  private boolean fixHeader = true;
  private boolean renderFooter = true;
  private boolean fixFooter = true;

  public boolean isRenderHeader() {
    return renderHeader;
  }

  public void setRenderHeader(boolean renderHeader) {
    this.renderHeader = renderHeader;
  }

  public boolean isFixHeader() {
    return fixHeader;
  }

  public void setFixHeader(boolean fixHeader) {
    this.fixHeader = fixHeader;
  }

  public boolean isRenderFooter() {
    return renderFooter;
  }

  public void setRenderFooter(boolean renderFooter) {
    this.renderFooter = renderFooter;
  }

  public boolean isFixFooter() {
    return fixFooter;
  }

  public void setFixFooter(boolean fixFooter) {
    this.fixFooter = fixFooter;
  }
}
